==> alan_voice-0.6.4.tar.gz: lib/alan_voice.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

import 'alan_callback.dart';

typedef void CommandCallbackFunction(CommandCallback command);

class AlanVoice {
  static const MethodChannel _channel = const MethodChannel('alan_voice');

  static const EventChannel _callBackChannel =
      const EventChannel('alan_voice_callback');

  static const String PLUGIN_VERSION = "0.6.4";

  static List<CommandCallbackFunction> callbacks = List();

  static void init() {
    _channel.setMethodCallHandler((MethodCall call) async {
      print("Got callback: ${call.method}");
      return true;
    });
  }

  static void _handleDialogState(String newState) {
    print("New dialog state is $newState");
  }

  static void _handleCommand(String payload) {
    print("Got command: $payload");
    callbacks.forEach((e) => e(CommandCallback(payload)));
  }

  static Future<String> get version async {
    String version = await _channel.invokeMethod('getVersion');
    version = "Plugin version: $PLUGIN_VERSION\n$version";
    return version;
  }

  static void showButton() async {
    await _channel.invokeMethod('showButton');
  }

  static void initButton(String projectId) async {
    await _channel
        .invokeMethod('initButton', <String, String>{"projectId": projectId});

    _callBackChannel.receiveBroadcastStream().listen((dynamic event) {
      if (event is List) {
        var method = event[0] as String;
        switch (method) {
          case "dialog_state_changed":
            _handleDialogState(event[1]);
            break;
          case "command":
            _handleCommand(event[1]);
            break;
          default:
            print("Unknown event type $method");
        }
      } else {
        print("Event is not a list, but $event");
      }
    }, onError: (dynamic error) {
      print("Got error in callbacks: $error");
    });
  }

  static Future<ScriptCallback> call(String method, String args) async {
    List<dynamic> result = await _channel.invokeMethod('callScript',
        <String, String>{"method_name": method, "method_args": args});

    return ScriptCallback(
        result[0].toString(), result[1].toString(), result[2].toString());
  }

  static void setVisuals(String visuals) async {
    _channel.invokeMethod('setVisuals',
        <String, String>{"visuals": visuals});
  }

  static void createButton() async {
    await _channel.invokeMethod('createButton');
  }
}

==> alan_voice-0.6.6.tar.gz: lib/alan_voice.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

import 'alan_callback.dart';

typedef void CommandCallbackFunction(CommandCallback command);

class AlanVoice {
  static const MethodChannel _channel = const MethodChannel('alan_voice');

  static const EventChannel _callBackChannel =
      const EventChannel('alan_voice_callback');

  static const String PLUGIN_VERSION = "0.6.6";

  static List<CommandCallbackFunction> callbacks = List();

  static void init() {
    _channel.setMethodCallHandler((MethodCall call) async {
      print("Got callback: ${call.method}");
      return true;
    });
  }

  static void _handleDialogState(String newState) {
    print("New dialog state is $newState");
  }

  static void _handleCommand(String payload) {
    print("Got command: $payload");
    callbacks.forEach((e) => e(CommandCallback(payload)));
  }

  static Future<String> get version async {
    String version = await _channel.invokeMethod('getVersion');
    version = "Plugin version: $PLUGIN_VERSION\n$version";
    return version;
  }

  static void showButton() async {
    await _channel.invokeMethod('showButton');
  }

  static void initButton(String projectId,
      [String server = "wss://tutor.alan.app",
      String dialogId,
      String authJson]) async {
    await _channel.invokeMethod('initButton', <String, String>{
      "projectId": projectId,
      "projectDialogId": dialogId,
      "projectServer": server,
      "projectAuthJson": authJson
    });

    _callBackChannel.receiveBroadcastStream().listen((dynamic event) {
      if (event is List) {
        var method = event[0] as String;
        switch (method) {
          case "dialog_state_changed":
            _handleDialogState(event[1]);
            break;
          case "command":
            _handleCommand(event[1]);
            break;
          default:
            print("Unknown event type $method");
        }
      } else {
        print("Event is not a list, but $event");
      }
    }, onError: (dynamic error) {
      print("Got error in callbacks: $error");
    });
  }

  static Future<ScriptCallback> call(String method, String args) async {
    List<dynamic> result = await _channel.invokeMethod('callScript',
        <String, String>{"method_name": method, "method_args": args});

    return ScriptCallback(
        result[0].toString(), result[1].toString(), result[2].toString());
  }

  static void setVisuals(String visuals) async {
    _channel.invokeMethod('setVisuals', <String, String>{"visuals": visuals});
  }

  static void createButton() async {
    await _channel.invokeMethod('createButton');
  }
}
